@@ -1,9 +1,10 @@
+import argparse
 import sys
 import os
 import warnings
 from contextlib import contextmanager
 from pathlib import Path
-from typing import Iterator, IO, Optional
+from typing import Iterator, IO, Optional, TYPE_CHECKING
 from enum import Enum
 
 
@@ -12,21 +13,33 @@ try:
 except ImportError:
     curses = None  # Compiled w/o curses
 
-from .compat import is_windows
+from .compat import is_windows, cached_property
 from .config import DEFAULT_CONFIG_DIR, Config, ConfigFileError
 from .encoding import UTF8
 
 from .utils import repr_dict
+from .output.ui.palette import GenericColor
+
+if TYPE_CHECKING:
+    from rich.console import Console
 
 
-class Levels(str, Enum):
+class LogLevel(str, Enum):
+    INFO = 'info'
     WARNING = 'warning'
     ERROR = 'error'
 
 
-DISPLAY_THRESHOLDS = {
-    Levels.WARNING: 2,
-    Levels.ERROR: float('inf'),  # Never hide errors.
+LOG_LEVEL_COLORS = {
+    LogLevel.INFO: GenericColor.PINK,
+    LogLevel.WARNING: GenericColor.ORANGE,
+    LogLevel.ERROR: GenericColor.RED,
+}
+
+LOG_LEVEL_DISPLAY_THRESHOLDS = {
+    LogLevel.INFO: 1,
+    LogLevel.WARNING: 2,
+    LogLevel.ERROR: float('inf'),  # Never hide errors.
 }
 
 
@@ -40,6 +53,7 @@ class Environment:
     is used by the test suite to simulate various scenarios.
 
     """
+    args = argparse.Namespace()
     is_windows: bool = is_windows
     config_dir: Path = DEFAULT_CONFIG_DIR
     stdin: Optional[IO] = sys.stdin  # `None` when closed fd (#791)
@@ -52,6 +66,10 @@ class Environment:
     stderr_isatty: bool = stderr.isatty()
     colors = 256
     program_name: str = 'http'
+
+    # Whether to show progress bars / status spinners etc.
+    show_displays: bool = True
+
     if not is_windows:
         if curses:
             try:
@@ -149,14 +167,51 @@ class Environment:
             self.stdout = original_stdout
             self.stderr = original_stderr
 
-    def log_error(self, msg: str, level: Levels = Levels.ERROR) -> None:
-        if self.stdout_isatty and self.quiet >= DISPLAY_THRESHOLDS[level]:
+    def log_error(self, msg: str, level: LogLevel = LogLevel.ERROR) -> None:
+        if self.stdout_isatty and self.quiet >= LOG_LEVEL_DISPLAY_THRESHOLDS[level]:
             stderr = self.stderr  # Not directly /dev/null, since stderr might be mocked
         else:
             stderr = self._orig_stderr
-
-        stderr.write(f'\n{self.program_name}: {level}: {msg}\n\n')
+        rich_console = self._make_rich_console(file=stderr, force_terminal=stderr.isatty())
+        rich_console.print(
+            f'\n{self.program_name}: {level}: {msg}\n\n',
+            style=LOG_LEVEL_COLORS[level],
+            markup=False,
+            highlight=False,
+            soft_wrap=True
+        )
 
     def apply_warnings_filter(self) -> None:
-        if self.quiet >= DISPLAY_THRESHOLDS[Levels.WARNING]:
+        if self.quiet >= LOG_LEVEL_DISPLAY_THRESHOLDS[LogLevel.WARNING]:
             warnings.simplefilter("ignore")
+
+    def _make_rich_console(
+        self,
+        file: IO[str],
+        force_terminal: bool
+    ) -> 'Console':
+        from rich.console import Console
+        from httpie.output.ui.rich_palette import _make_rich_color_theme
+
+        style = getattr(self.args, 'style', None)
+        theme = _make_rich_color_theme(style)
+        # Rich infers the rest of the knowledge (e.g encoding)
+        # dynamically by looking at the file/stderr.
+        return Console(
+            file=file,
+            force_terminal=force_terminal,
+            no_color=(self.colors == 0),
+            theme=theme
+        )
+
+    # Rich recommends separating the actual console (stdout) from
+    # the error (stderr) console for better isolation between parts.
+    # https://rich.readthedocs.io/en/stable/console.html#error-console
+
+    @cached_property
+    def rich_console(self):
+        return self._make_rich_console(self.stdout, self.stdout_isatty)
+
+    @cached_property
+    def rich_error_console(self):
+        return self._make_rich_console(self.stderr, self.stderr_isatty)
